@@ -51,7 +51,7 @@ typedef struct {
 	gint white_time;
 	gint black_time;
 	gint tomove;
-	gint result;
+	GameResult result;
 	gchar *description;
 } EngineInfo;
 
