@@ -95,7 +95,10 @@ struct _EngineIcsPrivate
 #define NOTATION    29
 #define FLIP        30
 
-static GIOChannel *chan;
+static GIOChannel *chan = NULL;
+static gboolean have_read = FALSE;
+G_LOCK_DEFINE (ICS_INPUT);
+
 extern BoardWindow *main_board_window;
 
 static EngineClass *parent_class = NULL;
@@ -590,8 +593,15 @@ engine_ics_input (char *buf, int max)
 {
 	guint len;
 
+	if (have_read) {
+		have_read = FALSE;
+		return 0;
+	}
+		
 	g_io_channel_read (chan, buf, max, &len);
-
+	if (len < max)
+		have_read = TRUE;
+	
 	return len;
 }
 
@@ -755,7 +765,7 @@ engine_ics_update_board (EngineIcs *engine, char *boardstring)
 	if (rel >= -1 && rel <= 1)
 		icsinfo->info.result = GAME_PROGRESS;
 	else
-		icsinfo->info.result = NONE;
+		icsinfo->info.result = GAME_NONE;
 	
 	if (icsinfo->info.description)
 		g_free (icsinfo->info.description);
@@ -826,9 +836,11 @@ ei_input_cb (GIOChannel *source,
 {
 	int token;
 
+	G_LOCK (ICS_INPUT);
 	chan = source;
 	token = yylex (ENGINE_ICS (data));
-
+	G_UNLOCK (ICS_INPUT);
+	
 	return TRUE;
 }
 
@@ -882,5 +894,3 @@ ei_view_cb (GtkWidget *widget, gpointer data)
 		priv->list = g_list_remove (priv->list, elem->data);
 	}
 }
-
-
