@@ -26,6 +26,7 @@
 #endif
 
 #include <gnome.h>
+#include "makros.h"
 #include "engine_null.h"
 
 struct _EngineNullPrivate 
@@ -38,7 +39,8 @@ static void class_init (EngineNullClass *klass);
 static void init (EngineNull *null);
 
 static void engine_null_fill_menu (EngineNull *engine, GtkMenuShell *shell, gint pos);
-static void engine_null_move (EngineNull *engine, gint from, gint to);
+static void engine_null_move (EngineNull *engine, Square from, Square to);
+static void engine_null_expire (EngineNull *engine, gshort color);
 
 GtkType
 engine_null_get_type (void)
@@ -75,6 +77,7 @@ class_init (EngineNullClass *klass)
 
 	engine_klass->engine_fill_menu = (EngineFillMenu) engine_null_fill_menu;
 	engine_klass->engine_move = (EngineMove) engine_null_move;
+	engine_klass->engine_expire = (EngineExpire) engine_null_expire;
 }
 
 
@@ -110,7 +113,7 @@ engine_null_set_fill_menu (EngineNull *engine, EngineFillMenu fill_menu)
 }
 
 static void
-engine_null_move (EngineNull *engine, gint from, gint to)
+engine_null_move (EngineNull *engine, Square from, Square to)
 {
 	if (engine->move != NULL)
 		engine->move (ENGINE (engine), from, to);
@@ -122,3 +125,16 @@ engine_null_set_move (EngineNull *engine, EngineMove move)
 	engine->move = move;
 }
 
+static void
+engine_null_expire (EngineNull *engine, gshort color)
+{
+	if (engine->expire != NULL)
+		engine->expire (ENGINE (engine), color);
+}
+
+void 
+engine_null_set_expire (EngineNull *engine, EngineExpire expire)
+{
+	engine->expire = expire;
+}
+
