@@ -98,7 +98,7 @@ static guint nsymbols = sizeof (symbols) / sizeof (symbols[0]);
 static GScannerConfig scanner_config =
 {
   (
-   " \t\n\r"
+   " \t\r"
    )			/* cset_skip_characters */,
   (
    G_CSET_a_2_z
@@ -262,12 +262,11 @@ static int
 pgn_load_from_fp (FILE *fp, int len, int test, pgn_info *info, GameView *view)
 {
 	int ret;
-
-	char *buf = malloc(len);
+	char *buf = g_new (char, len);
 
 	fread (buf, len, 1, fp);
 	ret = pgn_game_load (buf, len, test, info, view);
-	free (buf);
+	g_free (buf);
 
 	return ret;
 }
@@ -442,6 +441,21 @@ pgn_game_load (const char *newbuf, int len, int test, pgn_info *info, GameView *
 		  }
 		  break;
 		}
+		case '%': /* PGN escape mechanism */
+		{
+		    debug_print(DEBUG_NONE, "Escape token:\n");
+		    while (1) {
+		      token2 = g_scanner_get_next_token(s);
+		      debug_print(DEBUG_VERBOSE, "Token: %d\n",token2);
+		      if (token2 == G_TOKEN_EOF) 
+			break;
+		      if (token2 == '\n') 
+			break;
+		    }
+		    break;
+		}
+		case  '\n':
+		        break;
 		default:
 			debug_print(DEBUG_NONE, "Unknown token: %d\n",token);
 			ret = FALSE;
@@ -489,7 +503,8 @@ pgn_header_load(GScanner *s, Pgn_Tag * tp)
 			value1 = g_scanner_cur_value(s);
 			goto finish;
 			break;
-	  
+		case  '\n':
+		        break;
 		default:
 			debug_print(DEBUG_NONE, "Unknown token: %d\n",token);
 			return;
