@@ -182,8 +182,8 @@ server_term_get_size (ServerTerm *term, guint *width, guint *height)
 	
 	priv = term->priv;
 
-	*width = ZVT_TERM (priv->term)->grid_width;
-	*height = ZVT_TERM (priv->term)->grid_height;
+	*width = ZVT_TERM (priv->term)->vx->vt.width;
+	*height = ZVT_TERM (priv->term)->vx->vt.height;
 }
 
 void
